function region = JR_ROI
% JR_ROI
%   r = JR_ROI computes the indices of a region of interest
%
% Output:
%   r [vector]
%       vector of indices of the region of interest
%
% 2014-08-06 --------------------------------------------------------------
% Matthias J. Ehrhardt
% CMIC, University College London, UK 
% matthias.ehrhardt.11@ucl.ac.uk
% http://www.cs.ucl.ac.uk/staff/ehrhardt/software.html
%
% -------------------------------------------------------------------------
% Copyright 2014 University College London
%
% Licensed under the Apache License, Version 2.0 (the "License");
% you may not use this file except in compliance with the License.
% You may obtain a copy of the License at
%
%   http://www.apache.org/licenses/LICENSE-2.0
%
% Unless required by applicable law or agreed to in writing, software
% distributed under the License is distributed on an "AS IS" BASIS,
% WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
% See the License for the specific language governing permissions and
% limitations under the License.
% ------------------------------------------------------------------------- 

    size_image = [128 128];
    region = zeros(size_image);
    region(52:77,7:122) = 1;
    
    for i = 1 : 128
        for j = 1 : 128
            r = sqrt((i-(size_image(1)+1)/2)^2 + (j-(size_image(2)+1)/2)^2);
            if r < 49 && r > 29
                region(i,j) = 1;
            end
        end
    end    
    
    region = find(region);
    
end