function c = JR_colour2colour(c1,c2,N)
% JR_colour2colour
%   c = JR_colour2colour(c1,c2,N) creates a (linear) colourmap from colour 
% c1 to colour c2 of length N.
% 
% Input:    
%   c1 [vector]              
%       RGB code for the first colour
%
%   c2 [vector]              
%       RGB code for the second colour
%
%   N [int]              
%       length of the colourmap
%
% Output:    
%   c [matrix]              
%       output colourmap
%
% 2014-08-06 --------------------------------------------------------------
% Matthias J. Ehrhardt
% CMIC, University College London, UK 
% matthias.ehrhardt.11@ucl.ac.uk
% http://www.cs.ucl.ac.uk/staff/ehrhardt/software.html
%
% -------------------------------------------------------------------------
% Copyright 2014 University College London
%
% Licensed under the Apache License, Version 2.0 (the "License");
% you may not use this file except in compliance with the License.
% You may obtain a copy of the License at
%
%   http://www.apache.org/licenses/LICENSE-2.0
%
% Unless required by applicable law or agreed to in writing, software
% distributed under the License is distributed on an "AS IS" BASIS,
% WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
% See the License for the specific language governing permissions and
% limitations under the License.
% -------------------------------------------------------------------------

    c = zeros(N,3);
    
    for k = 1 : 3
        c(:,k) = linspace(c1(k),c2(k),N);
    end
    
end